﻿using InfragisticsMvcApp3.Models;
using System.Collections.Generic;
using System.Linq;
using System.Web.Mvc;

namespace InfragisticsMvcApp3.Controllers
{
    public class HomeController : Controller
    {
        //
        // GET: /Home/

        public ActionResult Index()
        {

            //This object will serve as the basis for binding to data
            //on the Index.cshtml View with the MVC Helpers. See:
            //@model = OctaneUIWebApplication5.Models.CustomersViewModel
            var viewModel = new CustomersViewModel
            {
                //IEnumerable of Customer Objects
                Customers = GetCustomers(),

                //IEnumerable of CustomerCountSummary Objects
                //For use with binding to the Chart
                CustomerCountSummaries = GetCustomerCounts()
            };

            return View(viewModel);
        }

        //This method aggregates the Customer data into a format that is easily
        //consumed by the Chart
        private IEnumerable<CustomerCountSummary> GetCustomerCounts()
        {
            var customers = GetCustomers();
            var active = from c in customers
                         where c.IsActive
                         select c;

            var inActive = from c in customers
                           where (c.IsActive == false)
                           select c;

            return new List<CustomerCountSummary> { 
                new CustomerCountSummary { CategoryLabel = "Active", CustomerCount = active.Count() },
                new CustomerCountSummary { CategoryLabel = "Inactive", CustomerCount = inActive.Count() }
            };
        }

        private IEnumerable<Customer> GetCustomers()
        {
            return new List<Customer>
            {
                new Customer { ID=1, Name="John Smith", IsActive=true },
                new Customer { ID=2, Name="Bob Richards", IsActive=false },
                new Customer { ID=3, Name="Marge Wright", IsActive=false },
                new Customer { ID=4, Name="Dwight Long", IsActive=true },
                new Customer { ID=5, Name="Amy Grant", IsActive=true },
            };
        }
    }
}
